@@ -6,7 +6,8 @@
 import sys
 
 from airbyte_cdk.entrypoint import launch
-from source_aws_cloudtrail import SourceAwsCloudtrail
+
+from .source import SourceAwsCloudtrail
 
 
 def run():
